#
# spec file for package python-minio
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15_python_module_pythons}
Name:           python-minio
Version:        7.1.16
Release:        2.1
Summary:        Minio library for Amazon S3 compatible cloud storage
License:        Apache-2.0
URL:            https://github.com/minio/minio-py
Source:         https://files.pythonhosted.org/packages/source/m/minio/minio-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-certifi
Requires:       python-urllib3
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module urllib3}
# /SECTION
%python_subpackages

%description
Minio library for Amazon S3 compatible cloud storage.

%prep
%autosetup -p1 -n minio-%{version}
mv docs/zh_CN/API.md docs/API_zh_CN.md
sed -i -e '/configparser/d' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README*.md docs/API*.md examples/
%license LICENSE
%{python_sitelib}/minio
%{python_sitelib}/minio-%{version}.dist-info

%changelog
* Fri Mar 29 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Fri Sep  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 7.1.16:
  * Update deprecated mc admin policy commands
  * update release references to master in README.md
  * Fix upload snowball objects with staging file
  * Add generic AWS S3 domain support
  * upload_snowball_object(): seek stream to 0 before upload
  * Revert "list_objecst: fix parsing user metadata as per
    MinIO server (#1240)"
  * Disable multipart upload for upload_snowball_objects() api.
  * Remove locale usage for datetime parsing
  * fix policy as a string in presigned_post_policy() API
  * Add cert_check flag to main class constructor
- Switch to pyproject and autosetup macros.
- Stop using greedy globs in %%files.
- Clean up unneeded {Build,}Requires.
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 7.1.14:
  * Have single GitHub workflow YAML
  * fget_object(): create tmp_file_path string generically
  * Add upload_snowball_objects() API
  * checks: ignore broad-exception-raised pylint error
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to 7.1.13:
  * Use Apache license SPDX identifier
  * fix usage of deprecated urllib3.Response.getheaders()
  * Fix typos and add codespell GitHub Action
  * Expose fetch-owner in the api for list_object
  * Add python 3.11 support
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 7.1.12:
  What's Changed
  fix documentation display composing by @j13tw in #1231
  fget_object(): add progress support by @moon-jong in #1235
  Updating documentation links to new URLs by @djwfyi in #1239
  list_objects: fix parsing user metadata as per MinIO server by @harshavardhana in #1240
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 7.1.11:
  select: yield available payload fully by requested num_bytes by @kldtz in #1225
- Update to version 7.1.10:
  fget_object(): remove resume support. by @balamurugana in #1215
  fix lifecycle config rule validation by @balamurugana in #1217
  error out if lifecycle rule has null filter by @balamurugana in #1219
  EventIterable: Reconnect on closed response. by @balamurugana in #1222
* Wed Jun 15 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 7.1.9
  * allow hashlib.md5() calls to work with FIPS kernels by @BOPOHA in #1200
  * Handle 304 status code properly by @balamurugana in #1202
  * correct ValueError when part_size > MAX_PART_SIZE by @ernestang98 in #1205
  * Set minimum requirement to Python v3.7 by @balamurugana in #1209
* Thu Mar 24 2022 pgajdos@suse.com
- version update to 7.1.5
  7.1.5
  - ----
  Add AssumeRoleWithCertificate credential provider. by @balamurugana in #1182
  7.1.4
  - ----
  docs: fix typo in object_lock config function name by @harshavardhana in #1176
  fix progress bar division by zero error by @harshavardhana in #1177
  Add policy unset method to minio admin by @federicober in #1180
  fix: lint checks and enable MINIO_CI_CD=1 for functional tests by @harshavardhana in #1181
  7.1.3
  - ----
  Update set_object_lock_config.py by @anooptp in #1170
  fix finding user's home directory in AWSConfigProvider/MinioClientConfigProvider by @nfioraio-ec in #1175
  fix EnvAWSProvider/EnvMinioProvider to fetch access/secret keys and session token always from os.environ by @nfioraio-ec in #1174
  7.1.2
  - ----
  fix: do not enforce role value for replicationConfig (#1166) (11/24/21) (Harshavardhana)
  fix: canonical request path if empty choose '/' (#1165) (11/24/21) (Harshavardhana)
- do not require python-mock for build
* Sun Oct 24 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 7.1.1:
  * Fix transition xml name in lifecycleconfig (#1142) (10/09/21) (Bala FA)
  * Remove nose tests and move to python unittest (#1152) (10/09/21) (Steve Kowalik)
  * Use unquote_plus() to decode url encoded value. (#1158) (10/09/21) (Bala FA)
  * Ignore cert addition if custom httpclient is passed (#1157) (10/08/21) (Anton Samokhvalov)
  * use f-string wherever possible (#1155) (10/08/21) (Bala FA)
  * Raise ValueError instead of returning in ChainedProvider (#1146) (09/01/21) (Bala FA)
- Drop remove-nose.patch, merged upstream.
* Wed Sep 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 7.1.0:
  * EventIterable: use looping instead of tail recursion in next() (#1126) (07/07/21) (Bala FA)
  * list_objects(): add url encoding type support. (#1107) (06/29/21) (Bala FA)
  * listen_bucket_notification(): return EventIterable object as controlled iterator. (#1118) (06/25/21) (Bala FA)
  * allow setting custom environment variables for mc admin subprocess (#1100) (05/24/21) (cbows)
  * fix error when mc admin response has a trailing newline (#1099) (05/24/21) (cbows)
  * Bucket: add string representation and equality method (#1095) (05/24/21) (Bahram Aghaei)
  * list_objects(): identify delete marker generically (#1106) (05/24/21) (Bala FA)
  * make_bucket: use region passed via constructor (#1103) (03/29/21) (Bala FA)
  * Optimize logic of read_part_data() (#1085) (02/21/21) (Bala FA)
  * Fix divided by zero error at part info computation. (#1083) (02/18/21) (Bala FA)
  * Convert timedelta.total_seconds() to integer in credential providers. (#1081) (02/12/21) (Brian Thorne)
  * fix data argument description of put_object() API (#1071) (01/29/21) (Bala FA)
  * fix getbytes() usage in make_bucket() API (#1073) (01/29/21) (Bala FA)
  * fix Retention properties usage (#1066) (01/27/21) (Bala FA)
  * fix Tagging.tags usage properly (#1061) (01/27/21) (Bala FA)
  * Add default 5 minutes timeout to default http client (#1069) (01/25/21) (Bala FA)
  * Enhance HTTP trace (#1056) (01/09/21) (Bala FA)
  * Allow empty prefix in Filter (#1053) (01/05/21) (Bala FA)
  * fix: bring back previous change to functional test script (#1045) (12/10/20) (Harshavardhana)
  * Remove configparser as dependency (#1046) (12/10/20) (Bala FA)
  * Python2 support has been removed.
  * Added support for S3 APIs related to object locking and versioning, tagging.
  * Added support for compose object.
  * fix: running functional tests issues (12/08/20) (Minio Trusted)
  * Enhance put_object() API to support more parameters (#1022) (12/04/20) (Bala FA)
  * Rename presigned_url() to get_presigned_url() (#1032) (12/03/20) (Bala FA)
  * Refactor PostPolicy implementation (#1023) (12/01/20) (Bala FA)
  * fix: allow tests to run properly on gateway setups (#1034) (11/28/20) (Harshavardhana)
  * error.code() is a property not function (11/28/20) (Harshavardhana)
  * Handle locale-safe time formats (#1020) (11/24/20) (Bala FA)
  * Make code property check optional in IamAwsProvider (#1025) (11/24/20) (Bala F:...skipping...
  * Simplify select_object_content() response stream (#1018) (12/02/20) (Bala FA)
  * Add compose_object() and enhance copy_object() APIs (#1021) (12/02/20) (Bala FA)
  * Refactor PostPolicy implementation (#1023) (12/01/20) (Bala FA)
  * fix: allow tests to run properly on gateway setups (#1034) (11/28/20) (Harshavardhana)
  * error.code() is a property not function (11/28/20) (Harshavardhana)
  * ignore NoSuchVersion returned in remove_objects (#1033) (11/28/20) (Harshavardhana)
  * Merge thread_pool.py into helpers.py (#1024) (11/25/20) (Bala FA)
  * Handle locale-safe time formats (#1020) (11/24/20) (Bala FA)
  * fix client grants provider example (#1027) (11/24/20) (Bala FA)
  * Make code property check optional in IamAwsProvider (#1025) (11/24/20) (Bala FA)
  * fix examples of {fget,get,stat}_object() APIs (#1028) (11/23/20) (Bala FA)
  * Merge definitions.py into helpers.py (#1017) (11/11/20) (Bala FA)
  * Normalize user metadata in request headers properly (#1016) (11/11/20) (Bala FA)
  * Update return type in put_object() and copy_object() API (#1012) (11/09/20) (Bala FA)
  * add {set,get}_object_retention() APIs (#986) (10/23/20) (Bala FA)
  * add {set,get,delete}_object_lock_config APIs (#985) (10/21/20) (Bala FA)
  * add {enable,disable,is}_object_legal_hold[_enabled] APIs (#987) (10/19/20) (Bala FA)
  * fix Host header in request correctly (#1004) (10/19/20) (Bala FA)
  * Handle location constraints inside API methods (#992) (10/14/20) (Bala FA)
  * Move http execution at one place (#968) (09/21/20) (Bala FA)
  * fix: Pass request parameters in query string in LDAPIdentityProvider. (#976) (09/13/20) (stepanko7)
  * IAMProvider accepts ECS IAM Task roles (#960) (08/22/20) (Nick Lavrov)
  * Ship missing credential files in MANIFEST.in (#962) (08/21/20) (Steve Kowalik)
- Drop use of SOURCE1 and SOURCE2, the files are now included in the sdist.
- Add patch remove-nose.patch:
  * Stop using nose methods.
* Wed Aug 19 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.0.0:
  * fix pydoc of all public methods in minio/api.py (#941) (08/03/20) (Bala FA)
  * Create CNAME (08/02/20) (Harshavardhana)
  * fix: doc rendering issue (#938) (07/17/20) (Andrei Vukolov)
  * Add object version-ID support (#923) (07/11/20) (Bala FA)
  * Added expiry_delta in IAM (#935) (07/09/20) (Felipe Ballesteros)
  * Less memory allocation with put_object() (#930) (06/19/20) (Anis Elleuch)
  * mention when proxy to be used (#928) (06/01/20) (Harshavardhana)
  * refactor minio.credentials (#901) (05/31/20) (Bala FA)
  * simplify constants definition and usage (#927) (05/29/20) (Bala FA)
  * fix trace to be printed before and after execution (#926)
    (05/25/20) (Bala FA)
  * change encoding of x-amz-copy-source in copy_object (#912)
    (05/09/20) (John Flickinger)
  * fix isort errors (#904) (05/03/20) (Bala FA)
  * simplify functional tests (#898) (04/30/20) (Bala FA)
  * add isort to keep imports sorted (#897) (04/20/20) (Bala FA)
  * add support for AssumeRole STS provider (#874) (04/16/20) (Brian Thorne)
  * Allow signing requests for services other than s3 in sign v4 (#893) (04/16/20) (Brian Thorne)
  * preserve x-amz-content-sha256 if specified in presign_v4 (#870)
    (04/13/20) (Vanessasaurus)
  * Rename urlencode and urldecode to quote and unquote (#875)
    (04/11/20) (Brian Thorne)
  * move to latest release for windows CI (#884) (04/10/20) (Harshavardhana)
  * Update MANIFEST.in to generate a complete sdist (#856) (04/08/20) (Denis Laxalde)
  * Adds missing 'minio/credentials/*.sample' files (#866)
    (04/06/20) (ebozduman)
  * remove deprecated cElementTree (04/07/20) (Karthikeyan Singaravelan)
  * fix github actions error while checking out (#869) (04/06/20) (kannappanr)
- Update SOURCE1 and SOURCE2 to pull from tests/unit, the upstream path
  changed.
* Wed Apr  1 2020 pgajdos@suse.com
- version update to 5.0.8
  * Fixes not subscriptable objects (#858) (03/09/20)
  * Support to put/get/delete default encryption configuration apis on a bucket (#855) (02/24/20)
  * Fix deprecation warnings due to invalid escape sequences. (#853) (02/10/20)
  * Add support for Amazon S3 Transfer Acceleration for presigned urls (#827) (02/02/20)
  * Add note on concurrent usage of Minio client (#849) (02/01/20)
  * python 3.8 compatibility (#847) (01/27/20)
  * cleanup whitespace and fix license header (#845) (01/22/20)
  * fix: relax bucket_name validation for existing buckets (#840) (01/22/20)
  * Implement credentials object (similar to minio-go) to enable AWS IAM (#817) (01/22/20)
- added sources
  https://github.com/minio/minio-py/issues/865
  + config.json.sample
  + credentials.sample
* Wed Jan 22 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to 5.0.6
  * Fix detecting a valid endpoint with new Python versions
  * Fix some typo in SELECT API doc
  * fget_object(): open temporary file on overwrite mode
- Update to 5.0.5
  * Increase presigned timeouts for functional tests
  * Remove future depdency for python3
  * Do not need to set max-keys, max-uploads and max-parts
- Update to 5.0.4
  * signV4: Avoid encoding ~ when found in the query part of
    the url
  * FIX: AttributeError at error.message
  * Strip port 80/443 from host
* Tue Oct  1 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 5.0.1
  * BREAKING API CHANGE: re-implement select_object_content
  * Remove white-space characters before parsing XML
  * Do not encode ~ in V4 S3 signing
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.21:
  * Doc: Fix error response URL link
  * Add support for ISO time with and without fractional seconds.
  * ObjectAccessed with Get and Head methods
  * list-objects-v2: Add start_after parameter
  * Implement select object
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.18:
  * Better error msg if metadata contains a non us-ascii character (#770) (06/12/19)
  * Fix Py3.7 warnings (#767) (06/11/19)
* Fri May 24 2019 pgajdos@suse.com
- version update to 4.0.17
  * Validate underscores in host names successfully
  * Use README.md instead of README.rst
* Fri May 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 4.0.16
  * Replaces Minio refs with MinIO and minio.io links with min.io
  * Use optimal part size determined by SDK
  * Adds debug code
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.13:
  * Add configurable part_size (#745)
* Fri Mar 15 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Add %%license and %%doc
- Update to v4.0.12
  * allow copy_object to set content-type
  * Add support for session tokens
  * Create MANIFEST.in
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v4.0.11
